# Building TELEMAC-MASCARET on Windows

This provides a set of scripts and a configuration file allowing to build TELEMAC-MASCARET on Windows using Mingw-w64.

## Prerequisites:

- **Git**: download it from [gitforwindows.org](https://gitforwindows.org/) and install it with the LFS extension.
- **CMake**: install the latest 64 bits version available from [cmake.org](https://cmake.org), and ensure that CMake `bin` directory is added to your `PATH` environment variable.<br>
Note: to install CMake without administrator rights, you need to download and extract the zip file and set your `PATH` manually.
- **Mingw-w64**: download the 12.2 version from [winlibs](https://github.com/brechtsanders/winlibs_mingw/releases/download/12.2.0-15.0.7-10.0.0-msvcrt-r4/winlibs-x86_64-posix-seh-gcc-12.2.0-mingw-w64msvcrt-10.0.0-r4.zip) and extract it to `C:\`.<br>
Note: if you don't install Mingw-w64 in `C:\`, you will need to add its `bin` directory to your `PATH`.

## Proxy configuration

If your computer is behind a proxy, you also need to set Windows proxy environment variables, such as below:
```
C:\>set http_proxy=http://vip-users.proxy.edf.fr:3131
C:\>set https_proxy=http://vip-users.proxy.edf.fr:3131
```

## Building and installing TELEMAC-MASCARET dependencies

TELEMAC-MASCARET can be built with or without several dependencies, which are listed below:
- MED (requires HDF5): add support for the MED file format.
- MPI: enable runtime parallelism, using the latest implementation of Microsoft MPI. Also requires:
    - METIS: used for partioning the mesh during a parallel run.
- MUMPS: parallel direct solver which is only used by ARTEMIS. Also requires:
    - MPI
    - OpenBLAS (includes LAPACK)
    - ScaLAPACK
- AED2: activate more processes in WAQTEL.
- GOTM: allow the use of the General Ocean Turbulence Model in TELEMAC-3D.

These dependencies can be installed using the provided `build-telemac-deps.bat` script, as follows:
```
C:\>build-telemac-deps C:\telemac-deps
```

This will **download** and **build** all dependencies, and **install** them to the provided path, which is `C:\telemac-deps` in this example.

## Building TELEMAC-MASCARET

Once you have built the dependencies, you can build TELEMAC-MASCARET:
- Clone the repository:
```
C:\>git clone https://gitlab.pam-retd.fr/otm/telemac-mascaret.git
```
- Copy the pysource batches from the `config` directory to TELEMAC-MASCARET `configs` directory:
```
C:\>xcopy /e/y wintel\config telemac-mascaret\configs\
```
- Edit both pysource batches to set the dependencies path, such as below:
```
set TELEMACDEPS=C:\telemac-deps
```
- Setup TELEMAC-MASCARET environment by launching one of the pysource batch:
```
C:\>telemac-mascaret\configs\pysource.win.bat
```
- Build TELEMAC-MASCARET:
```
C:\>compile_telemac.py
```
